Learn R Programming

ISO11784Tools (version 1.2.0)

convert_to_iso64bitl: Convert any recognised ISO11784/5 format to Raw Hexadecimal format, animal tag bit on the Left

Description

Convert any recognised ISO11784/5 format to Raw Hexadecimal format, animal tag bit on the Left

Usage

convert_to_iso64bitl(.data)

Value

A converted vector of character strings

Arguments

.data

A vector of character strings

Examples

Run this code
convert_to_iso64bitl(c('999012345678901','3E7.02DFDC1C36','EC383BFB439F0001'))

Run the code above in your browser using DataLab