Learn R Programming

ISO11784Tools (version 1.2.0)

convert_to_iso64bitr: Convert any recognised ISO11784/5 format to Raw Hexadecimal format, animal tag bit on the Right

Description

Convert any recognised ISO11784/5 format to Raw Hexadecimal format, animal tag bit on the Right

Usage

convert_to_iso64bitr(.data)

Value

A converted vector of character strings

Arguments

.data

A vector of character strings

Examples

Run this code
convert_to_iso64bitr(c('999012345678901','8000F9C2DFDC1C36','3E7.02DFDC1C37'))

Run the code above in your browser using DataLab